Struct Event
pub struct Event {
pub package_id: ObjectId,
pub module: Identifier,
pub sender: Address,
pub type_: StructTag,
pub contents: Vec<u8>,
}Expand description
An event
BCS
The BCS serialized form for this type is defined by the following ABNF:
event = object-id identifier address struct-tag bytesFields
package_id: ObjectIdPackage id of the top-level function invoked by a MoveCall command which triggered this event to be emitted.
module: IdentifierModule name of the top-level function invoked by a MoveCall command which triggered this event to be emitted.
sender: AddressAddress of the account that sent the transaction where this event was emitted.
type_: StructTagThe type of the event emitted
contents: Vec<u8>BCS serialized bytes of the event
Implementations
impl Event
impl Event
pub fn is_system_epoch_info_event(&self) -> bool
pub fn is_system_epoch_info_event(&self) -> bool
Checks if this is a SystemEpochInfoEvent of any version (V1 or V2).
pub fn is_system_epoch_info_event_v1(&self) -> bool
pub fn is_system_epoch_info_event_v1(&self) -> bool
Checks if this is
0x3::iota_system_state_inner::SystemEpochInfoEventV1.
pub fn is_system_epoch_info_event_v2(&self) -> bool
pub fn is_system_epoch_info_event_v2(&self) -> bool
Checks if this is
0x3::iota_system_state_inner::SystemEpochInfoEventV2.